@@ -21,6 +21,6 @@ def create_key(key_dir, key_fn):
                 os.makedirs(key_dir)
 
             key = SaltHandle()
-            file_write_bytes(path, key)
+            file_write_bytes(path, pickle.dumps(key))
     except ImportError:
         raise
