@@ -9,18 +9,16 @@ from exchangelib.errors import UnauthorizedError, TransportError
 import pathlib as pl
 
 
-class Toolbox(SQLQueue, LogHandle):
+class TB(SQLQueue, LogHandle):
     """
     A toolbox instance class that combines SQLQueue class, LogHandle class, and other various tools for use
     """
 
-    SQL_POOLSIZE = 10
     __local_config = None
     __main_config = None
     __pointer = None
 
-    def __init__(self, script_path, max_pool_size=SQL_POOLSIZE, pepper_key_fp=None, logging_path=None,
-                 logging_base_name=None):
+    def __init__(self, script_path, max_pool_size, pepper_key_fp, logging_path, logging_base_name):
         """
         Lets setup SQLQueue, Logging, Main Config, and Local Config
 
@@ -346,3 +344,12 @@ class Toolbox(SQLQueue, LogHandle):
     def __del__(self):
         SQLQueue.__del__(self)
         LogHandle.__del__(self)
+
+
+class Toolbox(TB):
+    SQL_POOLSIZE = 10
+
+    def __init__(self, script_path, max_pool_size=SQL_POOLSIZE, pepper_key_fp=None, logging_path=None,
+                 logging_base_name=None):
+        TB.__init__(self, script_path=script_path, max_pool_size=max_pool_size, pepper_key_fp=pepper_key_fp,
+                    logging_path=logging_path, logging_base_name=logging_base_name)
\ No newline at end of file
